==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/AbsoluteClipTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the clip time as an absolute time position in the media file.  The absolute time can point to a different position depending on whether the media file starts from a timestamp of zero or not.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
 * @property time The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
 */
public data class AbsoluteClipTimeArgs(
    public val odataType: Output<String>,
    public val time: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs =
        com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs.builder()
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .time(time.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AbsoluteClipTimeArgs].
 */
@PulumiTagMarker
public class AbsoluteClipTimeArgsBuilder internal constructor() {
    private var odataType: Output<String>? = null

    private var time: Output<String>? = null

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
     */
    @JvmName("kkrdiguwhyosipjc")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
     */
    @JvmName("adutlkdkpvjhatmf")
    public suspend fun time(`value`: Output<String>) {
        this.time = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
     */
    @JvmName("bqfijguhooraujny")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
     */
    @JvmName("etpcehimalnparbt")
    public suspend fun time(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.time = mapped
    }

    internal fun build(): AbsoluteClipTimeArgs = AbsoluteClipTimeArgs(
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        time = time ?: throw PulumiNullFieldException("time"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/media/kotlin/inputs/AbsoluteClipTimeArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.media.kotlin.inputs

import com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Specifies the clip time as an absolute time position in the media file.  The absolute time can point to a different position depending on whether the media file starts from a timestamp of zero or not.
 * @property odataType The discriminator for derived types.
 * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
 * @property time The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
 */
public data class AbsoluteClipTimeArgs(
    public val odataType: Output<String>,
    public val time: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs> {
    override fun toJava(): com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs =
        com.pulumi.azurenative.media.inputs.AbsoluteClipTimeArgs.builder()
            .odataType(odataType.applyValue({ args0 -> args0 }))
            .time(time.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AbsoluteClipTimeArgs].
 */
@PulumiTagMarker
public class AbsoluteClipTimeArgsBuilder internal constructor() {
    private var odataType: Output<String>? = null

    private var time: Output<String>? = null

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
     */
    @JvmName("fftbuwvijiqicoyx")
    public suspend fun odataType(`value`: Output<String>) {
        this.odataType = value
    }

    /**
     * @param value The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
     */
    @JvmName("vdrksnljihyaqrgd")
    public suspend fun time(`value`: Output<String>) {
        this.time = value
    }

    /**
     * @param value The discriminator for derived types.
     * Expected value is '#Microsoft.Media.AbsoluteClipTime'.
     */
    @JvmName("dwlygphfacvpddgb")
    public suspend fun odataType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.odataType = mapped
    }

    /**
     * @param value The time position on the timeline of the input media. It is usually specified as an ISO8601 period. e.g PT30S for 30 seconds.
     */
    @JvmName("unrgdloklhrpsqrw")
    public suspend fun time(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.time = mapped
    }

    internal fun build(): AbsoluteClipTimeArgs = AbsoluteClipTimeArgs(
        odataType = odataType ?: throw PulumiNullFieldException("odataType"),
        time = time ?: throw PulumiNullFieldException("time"),
    )
}
